@@ -12,25 +12,24 @@ unless $config then
 end
 
 unless $page_data_source then
-#	$page_data_source = Wiki::FilePageDataSource.new($data_dir)
-#	$page_data_source = Wiki::PStorePageDataSource.new($data_dir)
-#	$page_data_source.use_cache = $use_cache 
-#	$page_data_source.use_memory_cache = $use_memory_cache 
 	$page_data_source = Wiki::FilePageDataSource.new($config['data_dir'])
 	$page_data_source.use_cache = $config['use_cache']
 	$page_data_source.use_memory_cache = $config['use_memory_cache']
 end
 
+unless $template_data_source then
+	$template_data_source = Wiki::TemplateDataSource.new($config['template_dir'])
+end
+
 class WikiServlet < WEBrick::HTTPServlet::AbstractServlet
 	def do_GET(req, res)
-		app = KakiRequestHandler.new($page_data_source, req.meta_vars, req.query);
+		app = KakiRequestHandler.new($page_data_source, $template_data_source);
 
-#		app.template_dir = $template_dir if $template_dir
-#		app.theme_dir = $theme_dir if $theme_dir
-#		app.theme_base_url = $theme_base_url if $theme_base_url
-		app.template_dir = $config['template_dir'] if $config['template_dir']
 		app.theme_dir = $config['theme_dir'] if $config['theme_dir']
 		app.theme_base_url = $config['theme_base_url']if $config['theme_base_url']
+
+		app.request_variables = req.meta_vars
+		app.request_parameters = req.query
 		app.main()
 		header = app.response_header
 		body = app.response_body
