@@ -8,17 +8,16 @@ require 'PageParser.rb'
 require 'ToWikiHtml.rb'
 require 'FilePageDataSource.rb'
 require 'PStorePageDataSource.rb'
+require 'TemplateDataSource.rb'
 
 class KakiRequestHandler
-	DEFAULT_TEMPLATE_DIR = './template'
 	DEFAULT_THEME_DIR = './theme'
 	DEFAULT_THEME_BASE_URL = './theme'
 
-	def initialize(page_data_source, variables, parameters)
+	def initialize(page_data_source, template_data_source)
 		self.reset();
 		self.page_data_source = page_data_source
-		self.request_variables = variables
-		self.request_parameters = parameters
+		self.template_data_source = template_data_source
 	end
 
 	def reset
@@ -26,6 +25,7 @@ class KakiRequestHandler
 		@exception = nil
 		@site_property = nil
 		@page_data_source = nil
+		@template_data_source = nil
 		@wiki2html = nil
 
 		@request_variables = nil
@@ -46,18 +46,12 @@ class KakiRequestHandler
 		@server_uri = nil
 		@site_property = nil
 
-		@template_dir = nil
 		@theme_base_url = nil
 		@theme_dir = nil
 	end
 
-	attr_writer 'template_dir'
-	def template_dir
-		unless @template_dir then
-			@template_dir = DEFAULT_TEMPLATE_DIR
-		end
-		@template_dir
-	end
+	attr 'request_variables', true
+	attr 'request_parameters', true
 
 	attr 'theme_dir', true
 	def theme_dir
@@ -185,9 +179,8 @@ class KakiRequestHandler
 
 protected
 
-	attr 'request_variables', true
-	attr 'request_parameters', true
 	attr 'page_data_source', true
+	attr 'template_data_source', true
 
 	attr_writer 'response_header'
 	attr_writer 'response_body'
@@ -682,7 +675,7 @@ protected
 			b[1]['source_time'] <=> a[1]['source_time']
 		}
 
-		date_hash = {} # key: date string "%Y-%m-%d", value: hash
+		last_modified_time = self.site_property()['last_modified_time']
 		page_list = pages.collect(){ |page_info|
 			page_data = nil
 			page_id = page_info[0]
@@ -690,7 +683,11 @@ protected
 
 			page_name, lang, version = self.page_data_source.parse_page_id(page_id)
 			unless version then
-				page_data = page_property['source_time'].to_data_hash
+				page_modified_time = page_property['source_time']
+				if page_modified_time > last_modified_time then
+					last_modified_time = page_modified_time 
+				end
+				page_data = page_modified_time.to_data_hash
 				page_data[:page_id_uri] = URI.escape(page_id)
 				page_data[:page_id] = CGI.escapeHTML(page_id)
 				page_data[:page_name] = CGI.escapeHTML(page_name)
@@ -705,14 +702,13 @@ protected
 		data[:page_list] = page_list
 		data[:server_uri] = self.server_uri
 
-		last_modified_time = self.site_property()['last_modified_time']
 		data.update(last_modified_time.to_data_hash)
 
 		make_response_from_template('kaki.rss')
 		self.response_header['Content-Type'] = "text/xml"
+		self.response_header['Last-Modified'] = CGI.rfc1123_date(last_modified_time) 
 	end
 
-
 	def admin_save_property()
 		admin_passwd = request_parameters['admin_passwd'].to_s.untaint
 		site_name = request_parameters['site_name'].to_s.untaint
@@ -1084,24 +1080,12 @@ protected
 		data.update(self.site_common_data())
 		data[:server_time] = Time.now.to_data_hash
 
-		# template file path
-		tmpl_path = nil
-		tmpl_lang = nil
-		self.request_language_list.each(){ |l|
-			path = "#{self.template_dir}/#{l}/#{tmpl_file}"
-			if File.file?(path) and File.readable?(path) then
-				tmpl_path = path
-				tmpl_lang = l
-				break;
-			end
-		}
-		tmpl =  File.readlines(tmpl_path).to_s
+		tmpl, tmpl_lang = self.template_data_source.template(tmpl_file, self.request_language_list)
 
 		self.response_header['Language'] = tmpl_lang if tmpl_lang
 		self.response_body = Misen.expand_text(Misen::STYLE_SGML, tmpl, self.data)
 	end
 
-
 	def append_referer(page_property)
 		referer = request_variables['HTTP_REFERER']
 		
